@@ -220,10 +220,9 @@ class FinXRest:
         df = pd.DataFrame(await self.get_options_timeslice(timeslice_datestamp, timeslice_width_seconds, underlying_symbol))
         print('vol_surface_inputs raw:', df)
         df['years_to_expiry'] = df.apply(lambda row: self._calc_years_to_expiry(row), axis=1)
-        clean_df = df.copy()
-        df_filtered = clean_df.loc[clean_df['years_to_expiry'] > 0]
+        df_filtered = df.loc[df['years_to_expiry'] > 0.0]
         df_filtered['strike_price'] = df_filtered.apply(lambda row: self._parse_strike_price(row), axis=1)
-        output_df = df_filtered[['years_to_expiry', 'strike_price', 'mark_iv']].copy()
+        output_df = df_filtered[['years_to_expiry', 'strike_price', 'mark_iv']]
         output_df.rename(columns={"years_to_expiry": "expiration", "strike_price": "price", "mark_iv": "price"})
         # must be expiration,strike,price
         #,redis_key,underlying_price,underlying_index,timestamp,state,settlement_price,open_interest,min_price,max_price,mark_price,mark_iv,last_price,interest_rate,instrument_name,index_price,estimated_delivery_price,bid_iv,best_bid_price,best_bid_amount,best_ask_price,best_ask_amount,ask_iv,vega,theta,rho,gamma,delta,volume,price_change,low,high
